@@ -1,3 +1,8 @@
+local base = require("packages.base")
+
+local package = pl.class(base)
+package._name = "pullquote"
+
 local typesetMark = function (open, setback, scale, color, mark)
   SILE.settings:temporarily(function ()
     SILE.call("pullquote:mark-font")
@@ -20,28 +25,27 @@ local typesetMark = function (open, setback, scale, color, mark)
   end)
 end
 
-local function init (class, _)
-
-  class:loadPackage("color")
-  class:loadPackage("raiselower")
-  class:loadPackage("rebox")
-
+function package:_init ()
+  base._init(self)
+  self:loadPackage("color")
+  self:loadPackage("raiselower")
+  self:loadPackage("rebox")
 end
 
-local function registerCommands (_)
+function package:registerCommands ()
 
-  SILE.registerCommand("pullquote:font", function (_, _)
+  self:registerCommand("pullquote:font", function (_, _)
   end, "The font chosen for the pullquote environment")
 
-  SILE.registerCommand("pullquote:author-font", function (_, _)
+  self:registerCommand("pullquote:author-font", function (_, _)
     SILE.settings:set("font.style", "italic")
   end, "The font style with which to typeset the author attribution.")
 
-  SILE.registerCommand("pullquote:mark-font", function (_, _)
+  self:registerCommand("pullquote:mark-font", function (_, _)
     SILE.settings:set("font.family", "Libertinus Serif")
   end, "The font from which to pull the quotation marks.")
 
-  SILE.registerCommand("pullquote", function (options, content)
+  self:registerCommand("pullquote", function (options, content)
     local author = options.author or nil
     local scale = options.scale or 3
     local color = options.color or "#999999"
@@ -72,20 +76,15 @@ local function registerCommands (_)
 
 end
 
-return {
-  init = init,
-  registerCommands = registerCommands,
-  documentation = [[\begin{document}
-
-The \autodoc:environment{pullquote} environment formats longer quotations in an indented
-blockquote block with decorative quotation marks in the margins.
+package.documentation = [[
+\begin{document}
+The \autodoc:environment{pullquote} environment formats longer quotations in an indented blockquote block with decorative quotation marks in the margins.
 
 Here is some text set in a pullquote environment:
 
 \begin[author=Anatole France]{pullquote}%
-An education is not how much you have committed to memory, or even how much you
-know. It is being able to differentiate between what you do know and what you
-do not know.
+An education is not how much you have committed to memory, or even how much you know.
+It is being able to differentiate between what you do know and what you do not know.
 \end{pullquote}
 
 Optional values are available for:
@@ -97,10 +96,10 @@ Optional values are available for:
 \item{\autodoc:parameter{scale} to change the relative size of the quote marks.}
 \end{itemize}
 
-If you want to specify what font the pullquote environment should use, you
-can redefine the \autodoc:command{\pullquote:font} command. By default it will be the same
-as the surrounding document. The font style used for the attribution line
-can likewise be set redefining \autodoc:command{\pullquote:author-font} and the font used for
-the quote marks can be set redefining \autodoc:command{\pullquote:mark-font}.
+If you want to specify what font the pullquote environment should use, you can redefine the \autodoc:command{\pullquote:font} command.
+By default it will be the same as the surrounding document.
+The font style used for the attribution line can likewise be set redefining \autodoc:command{\pullquote:author-font} and the font used for the quote marks can be set redefining \autodoc:command{\pullquote:mark-font}.
+\end{document}
+]]
 
-\end{document}]] }
+return package
